=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2011-03-18 14:55:53 +0000
+++ drizzled/cursor.cc	2011-03-18 16:18:56 +0000
@@ -636,8 +636,6 @@
 void
 Cursor::setTransactionReadWrite()
 {
-  ResourceContext *resource_context;
-
   /*
    * If the cursor has not context for execution then there should be no
    * possible resource to gain (and if there is... then there is a bug such
@@ -646,7 +644,6 @@
   if (not getTable()->in_use)
     return;
 
-  resource_context= getTable()->in_use->getResourceContext(getEngine());
   /*
     When a storage engine method is called, the transaction must
     have been started, unless it's a DDL call, for which the
@@ -655,9 +652,10 @@
     Unfortunately here we can't know know for sure if the engine
     has registered the transaction or not, so we must check.
   */
-  if (resource_context->isStarted())
+  ResourceContext& resource_context= *getTable()->in_use->getResourceContext(getEngine());
+  if (resource_context.isStarted())
   {
-    resource_context->markModifiedData();
+    resource_context.markModifiedData();
   }
 }
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-03-18 16:06:34 +0000
+++ drizzled/session.cc	2011-03-18 16:18:56 +0000
@@ -23,12 +23,16 @@
 
 #include <config.h>
 
+#include <boost/checked_delete.hpp>
+#include <boost/filesystem.hpp>
 #include <drizzled/copy_field.h>
 #include <drizzled/data_home.h>
+#include <drizzled/diagnostics_area.h>
 #include <drizzled/display.h>
 #include <drizzled/drizzled.h>
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
+#include <drizzled/ha_data.h>
 #include <drizzled/identifier.h>
 #include <drizzled/internal/iocache.h>
 #include <drizzled/internal/thread_var.h>
@@ -37,6 +41,7 @@
 #include <drizzled/item/empty_string.h>
 #include <drizzled/item/float.h>
 #include <drizzled/item/return_int.h>
+#include <drizzled/item/subselect.h>
 #include <drizzled/lock.h>
 #include <drizzled/plugin/authentication.h>
 #include <drizzled/plugin/authorization.h>
@@ -50,6 +55,7 @@
 #include <drizzled/pthread_globals.h>
 #include <drizzled/query_id.h>
 #include <drizzled/refresh_version.h>
+#include <drizzled/schema.h>
 #include <drizzled/select_dump.h>
 #include <drizzled/select_exists_subselect.h>
 #include <drizzled/select_export.h>
@@ -59,35 +65,28 @@
 #include <drizzled/select_to_file.h>
 #include <drizzled/session.h>
 #include <drizzled/session/cache.h>
+#include <drizzled/session/property_map.h>
+#include <drizzled/session/state.h>
+#include <drizzled/session/table_messages.h>
 #include <drizzled/show.h>
 #include <drizzled/sql_base.h>
+#include <drizzled/sql_lex.h>
+#include <drizzled/statement.h>
 #include <drizzled/table/singular.h>
 #include <drizzled/table_proto.h>
 #include <drizzled/tmp_table_param.h>
 #include <drizzled/transaction_services.h>
 #include <drizzled/user_var_entry.h>
+#include <drizzled/util/backtrace.h>
+#include <drizzled/util/find_ptr.h>
 #include <drizzled/util/functors.h>
-#include <drizzled/util/find_ptr.h>
 #include <plugin/myisam/myisam.h>
-#include <drizzled/item/subselect.h>
-#include <drizzled/statement.h>
-#include <drizzled/sql_lex.h>
-#include <drizzled/ha_data.h>
-#include <drizzled/diagnostics_area.h>
-#include <drizzled/session/state.h>
-#include <drizzled/session/table_messages.h>
 
 #include <algorithm>
 #include <climits>
 #include <fcntl.h>
 #include <sys/stat.h>
 
-#include <boost/filesystem.hpp>
-#include <boost/checked_delete.hpp>
-
-#include <drizzled/util/backtrace.h>
-#include <drizzled/schema.h>
-
 using namespace std;
 
 namespace fs= boost::filesystem;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-18 16:06:34 +0000
+++ drizzled/session.h	2011-03-18 16:18:56 +0000
@@ -82,16 +82,12 @@
   class Singular; 
 }
 
-<<<<<<< TREE
-typedef Item COND;
-=======
 namespace util
 {
   class Storable;
 }
 
-typedef class Item COND;
->>>>>>> MERGE-SOURCE
+typedef Item COND;
 
 class CopyField;
 class CreateField;
@@ -1398,12 +1394,8 @@
   int setup_conds(TableList *leaves, COND **conds);
   int lock_tables(TableList *tables, uint32_t count, bool *need_reopen);
 
-<<<<<<< TREE
-  util::Storable *getProperty(const std::string &arg)
-=======
   template <class T>
   T* getProperty(const std::string& name)
->>>>>>> MERGE-SOURCE
   {
     return static_cast<T*>(getProperty0(name));
   }

=== modified file 'drizzled/transaction_services.cc'
--- drizzled/transaction_services.cc	2011-03-07 12:31:41 +0000
+++ drizzled/transaction_services.cc	2011-03-18 16:18:56 +0000
@@ -330,17 +330,17 @@
   }
 
   TransactionContext *trans= &session.transaction.stmt;
-  ResourceContext *resource_context= session.getResourceContext(monitored, 0);
+  ResourceContext& resource_context= *session.getResourceContext(monitored, 0);
 
-  if (resource_context->isStarted())
+  if (resource_context.isStarted())
     return; /* already registered, return */
 
   assert(monitored->participatesInSqlTransaction());
   assert(not monitored->participatesInXaTransaction());
 
-  resource_context->setMonitored(monitored);
-  resource_context->setTransactionalStorageEngine(engine);
-  trans->registerResource(resource_context);
+  resource_context.setMonitored(monitored);
+  resource_context.setTransactionalStorageEngine(engine);
+  trans->registerResource(&resource_context);
 
   trans->no_2pc|= true;
 }
@@ -363,18 +363,18 @@
   }
 
   TransactionContext *trans= &session.transaction.stmt;
-  ResourceContext *resource_context= session.getResourceContext(monitored, 0);
+  ResourceContext& resource_context= *session.getResourceContext(monitored, 0);
 
-  if (resource_context->isStarted())
+  if (resource_context.isStarted())
     return; /* already registered, return */
 
   assert(monitored->participatesInXaTransaction());
   assert(monitored->participatesInSqlTransaction());
 
-  resource_context->setMonitored(monitored);
-  resource_context->setTransactionalStorageEngine(engine);
-  resource_context->setXaResourceManager(resource_manager);
-  trans->registerResource(resource_context);
+  resource_context.setMonitored(monitored);
+  resource_context.setTransactionalStorageEngine(engine);
+  resource_context.setXaResourceManager(resource_manager);
+  trans->registerResource(&resource_context);
 
   trans->no_2pc|= false;
 }

